@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic melodic ornamentation
 
-our $VERSION = '0.0501';
+our $VERSION = '0.0502';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -227,7 +227,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic melodic ornamentati
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -259,6 +259,12 @@ and is based on the arithmetic of each ornament.  The list B<pitch>
 can vary around the given pitch argument by the given offset, and also
 depends on the particular ornament re-phrasing.
 
+Since the point is likely to use MIDI-Perl to render these ornaments,
+to audio, it is handy to know that the pitches in these specifications
+can be translated to a readable format like this:
+
+  $spec = [ map { [ MIDI::Util::midi_format(@$_) ] } @$spec ];
+
 =head1 ATTRIBUTES
 
 =head2 scale_note
